@@ -28,6 +28,16 @@
 /* Indicate if the current machine uses 64 bit architecture */
 int arch64(void)
 {
-	struct utsname u;
-	return(!uname(&u) && strstr(u.machine, "64"));
+	struct utsname uts;
+	char *uname_m;
+	if (uname(&uts))
+		return(0);
+	if ((uname_m = getenv("UNAME_MACHINE"))) {
+		int l = strlen(uname_m);
+		if (l >= sizeof(uts.machine))
+			l = sizeof(uts.machine)-1;
+		memcpy(uts.machine, uname_m, l);
+		uts.machine[l] = '\0';
+	}
+	return(strstr(uts.machine, "64") != NULL);
 }
